@@ -1,7 +1,7 @@
 // SPDX-FileCopyrightText: 2023 Carl Schwan <carl@carlschwan.eu>
 // SPDX-License-Identifier: LGPL-2.1-or-later
 #pragma once
-#include <abstractapplication.h>
+#include "abstractapplication.h"
 
 class MailApplication : public AbstractApplication
 {
