@@ -5,7 +5,9 @@
 
 #include "mailmodel.h"
 #include <Akonadi/CollectionFilterProxyModel>
+#include <MailCommon/EntityCollectionOrderProxyModel>
 #include <QObject>
+
 namespace Akonadi
 {
 class CollectionFilterProxyModel;
@@ -39,7 +41,7 @@ public:
     MailCommon::EntityCollectionOrderProxyModel *foldersModel() const;
     MailModel *folderModel() const;
     Akonadi::Session *session() const;
-    QString selectedFolderName() const;
+    [[nodiscard]] QString selectedFolderName() const;
 
     Q_INVOKABLE void loadMailCollection(const QModelIndex &index);
     Q_INVOKABLE void moveToTrash(Akonadi::Item item);
@@ -48,6 +50,7 @@ public:
     Q_INVOKABLE void deleteCollection(const QModelIndex &index);
     Q_INVOKABLE void editCollection(const QModelIndex &index);
     Q_INVOKABLE QString resourceIdentifier(const QModelIndex &index);
+    Q_INVOKABLE void saveMail(const QUrl &fileUrl, const Akonadi::Item &item);
 
 Q_SIGNALS:
     void loadingChanged();
